@@ -1,6 +1,6 @@
 /*
     GNU OrgaDoc - organizes and converts your XML document pool.
-    Copyright (C) 2017 - 2018 Adam Bilbrough
+    Copyright (C) 2017 - 2023 Adam Bilbrough
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,10 +18,16 @@
 
 #include "main.h"
 
+#define FILE_BUFSIZ 256
+char BUFFER[FILE_BUFSIZ];
+size_t nread;
+
 void
 orgadoc_search(char *file)
 {
   FILE *f;
+
+  printf("\nDisplaying contents of %s\n\n",file);
   f = fopen(file, "r");
   if (f == NULL)
     {
